=========
Changelog
=========

Version 0.1.2 - 2021-03-21
==========================

- Add missing entry point to Speedtest source

Version 0.1.1 - 2021-03-21
==========================

- Fix typos in README.rst
- Add missing dependency
- New source: Speedtest

- Initial release
Version 0.1 - 2021-03-21
========================

- Initial release
- Sources: Awair, random numbers
- Filters: JSONPath
- Sinks: Pushover, Postgres, logs
